@@ -100,6 +100,10 @@ extract_numeric_time <- function(x, tz) {
       gmt <- x$gmtoff
     }
 
+    if (getRversion() >= "4.3.0") {
+      x <- as.POSIXlt(x)
+    }
+
     if (is.null(gmt)) {
       gmt <- 0.0
       x$zone <- default_tz()
@@ -107,7 +111,15 @@ extract_numeric_time <- function(x, tz) {
       gmt[is.na(gmt)] <- 0.0
     }
 
-    return(unclass(as.POSIXct(x, x$zone)) + gmt)
+    # with R 4.3.0 this has to be mapped
+    out <-
+      if (getRversion() >= "4.3.0") {
+        mapply(as.POSIXct, x = as.POSIXct(x), tz = x$zone %||% 0)
+      } else {
+        as.POSIXct(x, x$zone %||% "")
+      }
+
+    return(unclass(out) + gmt)
   }
 
   to_numeric_with_tz(x, tz)
@@ -125,7 +137,10 @@ to_numeric_with_tz <- function(x, tz) {
 
   out <- mapply(
     function(xi, tzi) {
-      o <- as.POSIXlt(xi, tz = tzi)
+      o <- as.POSIXlt(xi, tz = tzi, optional = TRUE)
+      if (is.na(o)) {
+        return(NA_real_)
+      }
       off <- o$gmtoff %||% 0.0
       as.double(o) + off
     },
