@@ -20,11 +20,12 @@ magrittr::`%>%`
 `%||%` <- function(x, y) {
   if (is.null(x)) y else x
 }
-
-`%len%` <- function(x, y) if (length(x)) x else y
-
-which0 <- function(x) which(x) %len% 0L
-
+`%len%` <- function(x, y) {
+  if (length(x)) x else y
+}
+which0 <- function(x) {
+  which(x) %len% 0L
+}
 # isTRUE, isFALSE, ...
 isNA <- function(x) {
   is.logical(x) && length(x) == 1L && is.na(x)
@@ -59,15 +60,14 @@ isNA <- function(x) {
 }
 
 # modified from https://github.com/tidyverse/purrr/blob/5aca9df41452f272fcef792dbc6d584be8be7167/R/utils.R
-
 use_color <- function() {
   rn("crayon") && crayon::has_color()
 }
 
-crayon_blue  <- function(x) if (use_color()) crayon::blue(x)  else x
-crayon_green <- function(x) if (use_color()) crayon::green(x) else x
-crayon_cyan  <- function(x) if (use_color()) crayon::cyan(x)  else x
-
+use_color <- function() { rn("crayon") && crayon::has_color() }
+crayon_blue  <- function(x) { if (use_color()) crayon::blue(x)  else x }
+crayon_green <- function(x) { if (use_color()) crayon::green(x) else x }
+crayon_cyan  <- function(x) { if (use_color()) crayon::cyan(x)  else x }
 #' Parse and evaluate text
 #'
 #' A wrapper for eval(parse(text = .))
@@ -80,10 +80,9 @@ ept <- function(x, envir = parent.frame()) {
   eval(parse(text = x), envir = envir)
 }
 
-
 # Removes object's attributes before printing
 print_no_attr <- function(x, ...) {
-  print(remove_attributes(x))
+  print(remove_attributes(x)) # nocovr
 }
 
 #' That
@@ -143,11 +142,9 @@ is_atomic0 <- function(x) {
   is.atomic(x) && !is.null(x)
 }
 
-
-cat0 <- function(...) cat(..., sep = "")
-catln <- function(...) cat(..., sep = "\n")
-charexpr <- function(x) as.character(as.expression(x))
-
+cat0 <- function(...) { cat(..., sep = "") }
+catln <- function(...) { cat(..., sep = "\n") }
+charexpr <- function(x) { as.character(as.expression(x)) }
 mark_temp <- function(ext = "") {
   if (!grepl("^[.]", ext) && !identical(ext, "") && !is.na(ext)) {
     ext <- paste0(".", ext)
@@ -163,7 +160,6 @@ mark_temp <- function(ext = "") {
   norm_path(tempfile(oc, fileext = ext))
 }
 
-
 check_is_vector <- function(x, mode = "any") {
   if (isS4(x) | inherits(x, c("data.frame", "matrix", "array")) | !is.vector(remove_attributes(x), mode)) {
     stop(deparse(substitute(x)), " must be a vector of mode ", mode, call. = FALSE)
@@ -217,7 +213,6 @@ check_interactive <- function() {
   stop("mark.check_interactive must be TRUE, FALSE, or NA")
 }
 
-
 try_formats <- function(date = FALSE) {
   x <- c(
     "%Y-%m-%d %H:%M:%OS",
@@ -231,10 +226,9 @@ try_formats <- function(date = FALSE) {
     NULL
   )
 
-  c(x, paste(x, "%Z"), if (date) c("%Y-%m-%d", "%Y/%m/%d", "%Y%m%d"))
+  c(x, if (date) c("%Y-%m-%d", "%Y/%m/%d", "%Y%m%d"))
 }
 
-
 has_char <- function(x) {
   if (!is.character(x)) {
     return(rep.int(FALSE, length(x)))
@@ -243,7 +237,6 @@ has_char <- function(x) {
   !is.na(x) & nzchar(x, keepNA = TRUE)
 }
 
-
 dupe_check <- function(x, n = getOption("mark.dupe.n", 5)) {
   n <- as.integer(n)
 
@@ -263,3 +256,21 @@ dupe_check <- function(x, n = getOption("mark.dupe.n", 5)) {
 
   invisible(NULL)
 }
+
+exattr <- function(x, which) {
+  attr(x, which = which, exact = TRUE)
+}
+
+# operating systems -------------------------------------------------------
+
+is_windows <- function() {
+  Sys.info()[["sysname"]] == "Windows"
+}
+
+is_macos <- function() {
+  Sys.info()[["sysname"]] == "Darwin"
+}
+
+is_linux <- function() {
+  Sys.info()[["sysname"]] == "Linux"
+}
